@@ -11,5 +11,5 @@ def msg_log(msg):
   dt = datetime.now()
   if DEBUG==1:
     f = open("/tmp/pydbro.log","a")
-    f.write(str(dt)+" "+msg)
+    f.write(str(dt)+" "+msg+"\n")
     f.close()
