@@ -16,6 +16,19 @@ connfile = "sqlmk_conn.json"
 constr = None
 dsn = None
 
+def get_mysql_db():
+    db=None
+    if os.path.exists("sqlmk_conn.json"):
+      f = open("sqlmk_conn.json", "r")
+      dbcontmp = f.read()
+      f.close()
+      constr = json.loads(dbcontmp)
+      #msg_log(str(constr))
+      if "database" in constr: 
+        db = constr["database"]
+        #msg_log(db)
+    return(db)
+
 def create_con():
     global con
     global constr
@@ -50,22 +63,27 @@ def qry2dict(qry, qry_params=()):
       con = create_con()
       cur = con.cursor()
       cur.execute(qry, qry_params)
-      #con.commit()
-      data = cur.fetchall()
       cols = []
-      for col in cur.description:
-        cols.append(col[0])
-      con.close()
-      if len(data) > 0:
-        i = 0
-        for col in cols:
-          res[col] = []
-          for row in data:
-            res[col].append(row[i])
-          i += 1
+      if cur.description is None:
+        con.commit()
+      else:
+        data = cur.fetchall()
+        for col in cur.description:
+          cols.append(col[0])
+        con.close()
+        if len(data) > 0:
+          i = 0
+          for col in cols:
+            res[col] = []
+            for row in data:
+              res[col].append(row[i])
+            i += 1
       return(res,cols)
     except Exception as e:
-      #traceback.print_exc(file=sys.stdout)
-      #print(str(e))
-      msg_log("ERROR : " +str(e) + qry)
+      tramsg=""
+      exc_type, exc_value, exc_traceback = sys.exc_info()
+      traces = traceback.extract_tb(exc_traceback)
+      for frame_summary in traces:
+        tramsg+="{} {}".format(frame_summary.name, frame_summary.lineno)
+      msg_log("ERROR : "+str(e)+" "+qry+" "+tramsg)
       pass
