@@ -40,6 +40,21 @@ def get_conn():
     global connstr
     return connstr
 
+def get_postgres_db():
+    db=None
+    if os.path.exists("sqlpk_conn.json"):
+      f = open("sqlpk_conn.json", "r")
+      dbcontmp = f.read()
+      f.close()
+      constr = json.loads(dbcontmp)
+      #msg_log(str(constr))
+      if "database" in constr: 
+        db = constr["database"]
+        #msg_log(db)
+    return(db)
+
+
+
 def qry2dict(qry, qry_params=()):
     global constr
     global con
@@ -63,8 +78,10 @@ def qry2dict(qry, qry_params=()):
           i += 1
       return(res,cols)
     except Exception as e:
-      #traceback.print_exc(file=sys.stdout)
-      #print(str(e))
-      msg_log("ERROR : " +str(e) + qry)
+      tramsg=""
+      exc_type, exc_value, exc_traceback = sys.exc_info()
+      traces = traceback.extract_tb(exc_traceback)
+      for frame_summary in traces:
+        tramsg+="{} {}".format(frame_summary.name, frame_summary.lineno)
+      msg_log("ERROR : "+str(e)+" "+qry+" "+tramsg)
       pass
- 
